@@ -9,6 +9,7 @@ package HTMLLinkExtractor;
 
 require HTML::Parser;
 @ISA = qw(HTML::Parser);
+$VERSION = "1.0";
 
 use strict;
 use vars qw(%LINK_ELEMENT);
@@ -18,7 +19,6 @@ use vars qw(%LINK_ELEMENT);
 (
 'a'      => 'href',
 'img'    => [qw(longdesc usemap)],
-'base'   => 'href',
 'link'   => 'href',
 'area'   => 'href',
 'frame'  => [qw(src longdesc)],
@@ -53,8 +53,10 @@ sub start
     my $a;
 
     if ($tag eq 'meta') {
-      if ($attr->{'http-equiv'} =~ /^refresh$/oi
-          && $attr->{'content'} =~ /.+?;\s*url\s*=\s*(.+)$/ois)
+      if (exists $attr->{'http-equiv'} &&
+          $attr->{'http-equiv'} =~ /^refresh$/oi &&
+          exists $attr->{'content'} &&
+          $attr->{'content'} =~ /.+?;\s*url\s*=\s*(.+)$/ois)
       {
         push(@links, $1);
       }
